@@ -39,7 +39,7 @@ type ('a, 'b) t = ('a, 'b) Hashtbl.t
 
 type statistics = Hashtbl.statistics
 
-(**{6 Base operations}*)
+(**{1 Base operations}*)
 
 val create : int -> ('a, 'b) t
 (** [Hashtbl.create n] creates a new, empty hash table, with
@@ -103,13 +103,54 @@ val copy : ('a, 'b) t -> ('a, 'b) t
 val clear : ('a, 'b) t -> unit
 (** Empty a hash table. *)
 
+val reset : ('a, 'b) t -> unit
+(** Empty a hash table and shrink the size of the bucket table
+    to its initial size.
+    @since 3.9.0 and OCaml 4.00 *)
+
 val stats : ('a, 'b) t -> statistics
 (** [Hashtbl.stats tbl] returns statistics about the table [tbl]:
     number of buckets, size of the biggest bucket, distribution of
     buckets by size.
     @since 4.00.0 and batteries 3.5.1 *)
 
-(**{6 Enumerations}*)
+(** {1 Sequences} *)
+
+##V>=4.07##val to_seq : ('a,'b) t -> ('a * 'b) Seq.t
+##V>=4.07##(** Iterate on the whole table.  The order in which the bindings
+##V>=4.07##    appear in the sequence is unspecified. However, if the table contains
+##V>=4.07##    several bindings for the same key, they appear in reversed order of
+##V>=4.07##    introduction, that is, the most recent binding appears first.
+##V>=4.07##
+##V>=4.07##    The behavior is not specified if the hash table is modified
+##V>=4.07##    during the iteration.
+##V>=4.07##
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+##V>=4.07##
+##V>=4.07##val to_seq_keys : ('a,_) t -> 'a Seq.t
+##V>=4.07##(** Same as [Seq.map fst (to_seq m)]
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+##V>=4.07##
+##V>=4.07##val to_seq_values : (_,'b) t -> 'b Seq.t
+##V>=4.07##(** Same as [Seq.map snd (to_seq m)]
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+##V>=4.07##
+##V>=4.07##val add_seq : ('a,'b) t -> ('a * 'b) Seq.t -> unit
+##V>=4.07##(** Add the given bindings to the table, using {!add}
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+##V>=4.07##
+##V>=4.07##val replace_seq : ('a,'b) t -> ('a * 'b) Seq.t -> unit
+##V>=4.07##(** Add the given bindings to the table, using {!replace}
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+##V>=4.07##
+##V>=4.07##val of_seq : ('a * 'b) Seq.t -> ('a, 'b) t
+##V>=4.07##(** Build a table from the given bindings. The bindings are added
+##V>=4.07##    in the same order they appear in the sequence, using {!replace_seq},
+##V>=4.07##    which means that if two pairs have the same key, only the latest one
+##V>=4.07##    will appear in the table.
+##V>=4.07##    @since 3.9.0 and OCaml 4.07 *)
+
+(**{1 Enumerations}*)
 
 val keys : ('a,'b) t -> 'a BatEnum.t
 (** Return an enumeration of all the keys of a hashtable.
@@ -125,7 +166,7 @@ val enum : ('a, 'b) t -> ('a * 'b) BatEnum.t
 val of_enum : ('a * 'b) BatEnum.t -> ('a, 'b) t
 (** Create a hashtable from a (key,value) enumeration. *)
 
-(**{6 Lists}*)
+(**{1 Lists}*)
 
 val of_list : ('a * 'b) list -> ('a, 'b) t
 (** Create a hashtable from a list of (key,value) pairs.
@@ -139,7 +180,7 @@ val bindings : ('a, 'b) t -> ('a * 'b) list
 (** Alias for [to_list].
     @since 2.6.0 *)
 
-(**{6 Searching}*)
+(**{1 Searching}*)
 
 val find : ('a, 'b) t -> 'a -> 'b
 (** [Hashtbl.find tbl x] returns the current binding of [x] in [tbl],
@@ -159,6 +200,10 @@ val find_option : ('a,'b) t -> 'a -> 'b option
 (** Find a binding for the key, or return [None] if no
     value is found *)
 
+val find_opt : ('a, 'b) t -> 'a -> 'b option
+(** [Stdlib]-compatible alias for {!find_option}.
+    @since 3.9.0 *)
+
 val exists : ('a -> 'b -> bool) -> ('a,'b) t -> bool
 (** Check if at least one key-value pair satisfies [p k v] *)
 
@@ -169,7 +214,7 @@ val mem : ('a, 'b) t -> 'a -> bool
   (** [exists h k] returns true is at least one item with key [k] is
       found in the hashtable. *)*)
 
-(**{6 Traversing}
+(**{1 Traversing}
 
    A number of higher-order functions are provided to allow
    purely functional traversal or transformation of hashtables.
@@ -277,7 +322,7 @@ val merge_all: ('a -> 'b list -> 'c list -> 'd list) ->
     @since 2.10.0
 *)
 
-(** {6 The polymorphic hash primitive}*)
+(** {1 The polymorphic hash primitive}*)
 
 val hash : 'a -> int
 (** [Hashtbl.hash x] associates a positive integer to any value of
@@ -287,16 +332,16 @@ val hash : 'a -> int
     structures. *)
 
 
-(** {6 Boilerplate code}*)
+(** {1 Boilerplate code}*)
 
-(** {7 Printing}*)
+(** {2 Printing}*)
 
 val print :  ?first:string -> ?last:string -> ?sep:string -> ?kvsep:string ->
   ('a BatInnerIO.output -> 'b -> unit) ->
   ('a BatInnerIO.output -> 'c -> unit) ->
   'a BatInnerIO.output -> ('b, 'c) t -> unit
 
-(** {6 Override modules}*)
+(** {1 Override modules}*)
 
 (**
    The following modules replace functions defined in {!Hashtbl} with functions
@@ -366,7 +411,7 @@ sig
                  left:('a, 'b) t -> right:('a, 'c) t -> ('a, 'd) t
 end
 
-(** {6 Functorial interface} *)
+(** {1 Functorial interface} *)
 
 module type HashedType =
 sig
@@ -399,6 +444,7 @@ sig
   val length : 'a t -> int
   val is_empty : 'a t -> bool
   val clear : 'a t -> unit
+  val reset : 'a t -> unit
   val copy : 'a t -> 'a t
   val add : 'a t -> key -> 'a -> unit
   val remove : 'a t -> key -> unit
@@ -407,6 +453,8 @@ sig
   val find_all : 'a t -> key -> 'a list
   val find_default : 'a t -> key ->  'a -> 'a
   val find_option : 'a t -> key -> 'a option
+  val find_opt : 'a t -> key -> 'a option
+
   val replace : 'a t -> key -> 'a -> unit
   val mem : 'a t -> key -> bool
   val iter : (key -> 'a -> unit) -> 'a t -> unit
@@ -429,6 +477,14 @@ sig
   val merge_all : (key -> 'a list -> 'b list -> 'c list) ->
     'a t -> 'b t -> 'c t
   val stats : 'a t -> statistics
+
+##V>=4.07##  val to_seq : 'a t -> (key * 'a) Seq.t
+##V>=4.07##  val to_seq_keys : _ t -> key Seq.t
+##V>=4.07##  val to_seq_values : 'a t -> 'a Seq.t
+##V>=4.07##  val add_seq : 'a t -> (key * 'a) Seq.t -> unit
+##V>=4.07##  val replace_seq : 'a t -> (key * 'a) Seq.t -> unit
+##V>=4.07##  val of_seq : (key * 'a) Seq.t -> 'a t
+
   val keys : 'a t -> key BatEnum.t
   val values : 'a t -> 'a BatEnum.t
   val enum : 'a t -> (key * 'a) BatEnum.t
@@ -440,7 +496,7 @@ sig
     ('a BatInnerIO.output -> 'b -> unit) ->
     'a BatInnerIO.output -> 'b t -> unit
 
-  (** {6 Override modules}*)
+  (** {1 Override modules}*)
 
   (**
      The following modules replace functions defined in {!Hashtbl} with functions
@@ -512,7 +568,7 @@ sig
 end
 (** The output signature of the functor {!Hashtbl.Make}. *)
 
-module Make (H : HashedType) : S with type key = H.t
+module Make (H : HashedType) : S with type key = H.t and type 'a t = 'a Hashtbl.Make (H).t
 (** Functor building an implementation of the hashtable structure.
     The functor [Hashtbl.Make] returns a structure containing
     a type [key] of keys and a type ['a t] of hash tables
@@ -532,7 +588,7 @@ sig
   type ('a, 'b, 'c) t constraint 'c = [< `Read | `Write ]
   (** The type of a hashtable. *)
 
-  (**{6 Constructors}*)
+  (**{1 Constructors}*)
 
   val create : int -> ('a, 'b, _) t
 
@@ -562,7 +618,7 @@ sig
 
       This operation involves no copying.*)
 
-  (**{6 Base operations}*)
+  (**{1 Base operations}*)
 
   val length : ('a, 'b, _) t -> int
   val is_empty : ('a, 'b, _) t -> bool
@@ -574,7 +630,7 @@ sig
   val clear : ('a, 'b, [>`Write]) t -> unit
   val stats : ('a, 'b, _) t -> statistics
 
-  (**{6 Searching}*)
+  (**{1 Searching}*)
 
   val find : ('a, 'b, [>`Read]) t -> 'a -> 'b
   val find_all : ('a, 'b, [>`Read]) t -> 'a -> 'b list
@@ -588,7 +644,7 @@ sig
     (** [exists h k] returns true is at least one item with key [k] is
         found in the hashtable. *)*)
 
-  (**{6 Traversing}*)
+  (**{1 Traversing}*)
 
   val iter : ('a -> 'b -> unit) -> ('a, 'b, [>`Read]) t -> unit
   val for_all : ('a -> 'b -> bool) -> ('a, 'b, [>`Read]) t -> bool
@@ -606,7 +662,7 @@ sig
   val merge_all : ('key -> 'a list -> 'b list -> 'c list) ->
                   ('key, 'a, [>`Read]) t -> ('key, 'b, [>`Read]) t -> ('key, 'c, _) t
 
-  (**{6 Conversions}*)
+  (**{1 Conversions}*)
 
   val keys : ('a,'b, [>`Read]) t -> 'a BatEnum.t
   val values : ('a, 'b, [>`Read]) t -> 'b BatEnum.t
@@ -615,16 +671,16 @@ sig
   val to_list : ('a, 'b, [>`Read]) t -> ('a * 'b) list
   val of_list : ('a * 'b) list -> ('a, 'b, _) t
 
-  (** {6 Boilerplate code}*)
+  (** {1 Boilerplate code}*)
 
-  (** {7 Printing}*)
+  (** {2 Printing}*)
 
   val print :  ?first:string -> ?last:string -> ?sep:string -> ?kvsep:string ->
     ('a BatInnerIO.output -> 'b -> unit) ->
     ('a BatInnerIO.output -> 'c -> unit) ->
     'a BatInnerIO.output -> ('b, 'c, [>`Read]) t -> unit
 
-  (** {6 Override modules}*)
+  (** {1 Override modules}*)
 
   (** Operations on {!BatHashtbl.Cap} without exceptions.*)
   module Exceptionless :
