@@ -121,7 +121,7 @@ exception Input_closed
 exception Output_closed
 (** This exception is raised when reading on a closed output. *)
 
-(** {6 Standard inputs/outputs} *)
+(** {1 Standard inputs/outputs} *)
 
 val stdin : input
 (** Standard input, as per Unix/Windows conventions (by default, keyboard).
@@ -161,7 +161,7 @@ val stdnull: unit output
     ]
 *)
 
-(** {6 Standard API} *)
+(** {1 Standard API} *)
 
 val read : input -> char
 (** Read a single char from an input or raise [No_more_input] if
@@ -180,8 +180,10 @@ val nread : input -> int -> string
 
 val really_nread : input -> int -> string
 (** [really_nread i n] reads a string of exactly [n] characters
-    from the input. @raise No_more_input if at least [n] characters are
-    not available. @raise Invalid_argument if [n] < 0.
+    from the input.
+
+    @raise No_more_input if at least [n] characters are not available.
+    @raise Invalid_argument if [n] < 0.
 
     Example: [let read_md5 ch = really_nread ch 32]
 *)
@@ -205,10 +207,11 @@ val input : input -> Bytes.t -> int -> int -> int
 val really_input : input -> Bytes.t -> int -> int -> int
 (** [really_input ic s p len] reads exactly [len] characters from the
     input [ic], storing them in the string [s], starting at
-    position [p]. For consistency with {!BatIO.input} it returns
-    [len]. @raise No_more_input if at [len] characters are not
-    available. @raise Invalid_argument if [p] and [len] do not
-    designate a valid substring of [s].
+    position [p]. For consistency with {!BatIO.val-input} it returns
+    [len].
+
+    @raise No_more_input if at [len] characters are not available.
+    @raise Invalid_argument if [p] and [len] do not designate a valid substring of [s].
 
     Example: [let _ = really_input stdin b 0 3]
 *)
@@ -251,9 +254,10 @@ val output_substring : 'a output -> string -> int -> int -> int
 val really_output : 'a output -> Bytes.t -> int -> int -> int
 (** [really_output o s p len] writes exactly [len] characters from
     byte sequence [s] onto the the output, starting with the character
-    at offset [p]. For consistency with {!BatIO.output} it returns
-    [len]. @raise Invalid_argument if [p] and [len] do not designate
-    a valid subsequence of [s].
+    at offset [p]. For consistency with {!BatIO.val-output} it returns
+    [len].
+
+    @raise Invalid_argument if [p] and [len] do not designate a valid subsequence of [s].
 
     This function is useful for networking situations where the output
     buffer might fill resulting in not the entire substring being
@@ -308,7 +312,7 @@ val close_all : unit -> unit
 *)
 (**/**)
 
-(** {6 Creation of BatIO Inputs/Outputs}
+(** {1 Creation of BatIO Inputs/Outputs}
 
     To open a file for reading/writing, see {!File.open_in}
     and {!File.open_out}*)
@@ -356,7 +360,7 @@ val tab_out : ?tab:char -> int -> 'a output -> unit output
   (** [repeat n out] create an output in which every character or string is repeated
     [n] times to [out].*)*)
 
-(** {6 Utilities} *)
+(** {1 Utilities} *)
 
 val read_all : input -> string
 (** read all the contents of the input until [No_more_input] is raised. *)
@@ -395,7 +399,7 @@ external cast_output : 'a output -> unit output = "%identity"
 
 
 
-(** {6 Binary files API}
+(** {1 Binary files API}
 
     Here is some API useful for working with binary files, in particular
     binary files generated by C applications. By default, encoding of
@@ -419,8 +423,9 @@ val read_i16 : input -> int
 (** Read a signed 16-bit word. *)
 
 val read_i32 : input -> int
-(** Read a signed 32-bit integer. @raise Overflow if the
-    read integer cannot be represented as an OCaml 31-bit integer. *)
+(** Read a signed 32-bit integer.
+
+    @raise Overflow if the read integer cannot be represented as an OCaml 31-bit integer. *)
 
 val read_real_i32 : input -> int32
 (** Read a signed 32-bit integer as an OCaml int32. *)
@@ -501,8 +506,9 @@ sig
   (** Read a signed 16-bit word. *)
 
   val read_i32 : input -> int
-  (** Read a signed 32-bit integer. @raise Overflow if the
-          read integer cannot be represented as an OCaml 31-bit integer. *)
+  (** Read a signed 32-bit integer.
+
+      @raise Overflow if the read integer cannot be represented as an OCaml 31-bit integer. *)
 
   val read_real_i32 : input -> int32
   (** Read a signed 32-bit integer as an OCaml int32. *)
@@ -565,7 +571,7 @@ sig
 end
 
 
-(** {6 Bits API}
+(** {1 Bits API}
 
     This enable you to read and write from an BatIO bit-by-bit or several bits
     at the same time.
@@ -597,7 +603,7 @@ val drop_bits : in_bits -> unit
 
 
 (**
-   {6 Creating new types of inputs/outputs}
+   {1 Creating new types of inputs/outputs}
 *)
 
 
@@ -656,7 +662,7 @@ val create_out :
     Fully create an output by giving all the needed functions.
 
     @param write  Write one character to the output (see {!write}).
-    @param output Write a (sub)string to the output (see {!output}).
+    @param output Write a (sub)string to the output (see {!val-output}).
     @param flush  Flush any buffers of this output  (see {!flush}).
     @param close  Close this output. The output will be automatically
     flushed.
@@ -703,7 +709,7 @@ val wrap_out :
    issue.
 
    @param write  Write one character to the output (see {!write}).
-   @param output Write a (sub)string to the output (see {!output}).
+   @param output Write a (sub)string to the output (see {!val-output}).
    @param flush  Flush any buffers of this output  (see {!flush}).
    @param close  Close this output. The output will be automatically
    flushed.
@@ -734,7 +740,7 @@ val inherit_out:
 *)
 
 (**
-   {6 For compatibility purposes}
+   {1 For compatibility purposes}
 *)
 
 val input_channel : ?autoclose:bool -> ?cleanup:bool -> in_channel -> input
@@ -766,7 +772,7 @@ val to_input_channel : input -> in_channel
     libraries which can't be adapted. As a general rule, if
     you can avoid using this function, don't use it.*)
 
-(** {6 Generic BatIO Object Wrappers}
+(** {1 Generic BatIO Object Wrappers}
 
     These OO Wrappers have been written to provide easy support of
     BatIO by external libraries. If you want your library to support
@@ -813,7 +819,7 @@ val from_out_channel : #out_channel -> unit output
 val from_in_chars : #in_chars -> input
 val from_out_chars : #out_chars -> unit output
 
-(** {6 Enumeration API}*)
+(** {1 Enumeration API}*)
 
 val bytes_of : input -> int BatEnum.t
 (** Read an enumeration of unsigned 8-bit integers. *)
@@ -828,8 +834,9 @@ val i16s_of : input -> int BatEnum.t
 (** Read an enumartion of signed 16-bit words. *)
 
 val i32s_of : input -> int BatEnum.t
-(** Read an enumeration of signed 32-bit integers. @raise Overflow if the
-    read integer cannot be represented as an OCaml 31-bit integer. *)
+(** Read an enumeration of signed 32-bit integers.
+
+    @raise Overflow if the read integer cannot be represented as an OCaml 31-bit integer. *)
 
 val real_i32s_of : input -> int32 BatEnum.t
 (** Read an enumeration of signed 32-bit integers as OCaml [int32]s. *)
@@ -870,7 +877,7 @@ val default_buffer_size : int
 (**The default size for internal buffers.*)
 
 (**
-   {6 Thread-safety}
+   {1 Thread-safety}
 *)
 
 val synchronize_in : ?lock:BatConcurrent.lock -> input  -> input
@@ -899,7 +906,7 @@ val synchronize_out: ?lock:BatConcurrent.lock -> _ output -> unit output
 
 
 (**
-   {6 Thread-safety internals}
+   {1 Thread-safety internals}
 
    Unless you are attempting to adapt Batteries Included to a new model of
    concurrency, you probably won't need this.
@@ -935,14 +942,14 @@ val comb : ('a output * 'a output) -> 'a output
 val make_enum : (input -> 'a) -> input -> 'a BatEnum.t
 
 (**
-   {6 Debugging facilities}
+   {1 Debugging facilities}
 *)
 
 val get_output_id : _ output -> int
 val get_input_id  : input -> int
 
 module Incubator : sig
-  (** {6 Format-based pretty-printing} *)
+  (** {1 Format-based pretty-printing} *)
 
   module Array : sig
     val pp :
