@@ -19,6 +19,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
+##V>=5##module Pervasives = Stdlib
+
+(*$inject
+##V>=5##module Pervasives = Stdlib
+*)
 
 open BatNumber
 
@@ -227,12 +232,12 @@ module BaseSafeInt = struct
       operators with their safe counterparts *)
 
   let add a b =
-    let c = Pervasives.( + ) a b in
+    let c = a + b in
     if a < 0 && b < 0 && c >= 0 || a > 0 && b > 0 && c <= 0 then raise Overflow
     else c
 
   let sub a b =
-    let c = Pervasives.( - ) a b in
+    let c = a - b in
     if a < 0 && b > 0 && c >= 0 || a > 0 && b < 0 && c <= 0 then raise Overflow
     else c
 
@@ -256,7 +261,7 @@ module BaseSafeInt = struct
   (* Uses a formula taken from Hacker's Delight, chapter "Overflow Detection",
      plus a fast-path check (see comment above) *)
   let mul (a: int) (b: int) : int =
-    let open Pervasives in
+    (* let open Pervasives in *)
     let c = a * b in
     if (a lor b) asr mul_shift_bits = 0
     || not ((a = min_int && b < 0) || (b <> 0 && c / b <> a)) then
@@ -333,7 +338,7 @@ end
     let slow_mul a b = \
       if b = 0 then 0 \
       else if (abs a) > max_int / (abs b) then raise BatNumber.Overflow else a*b \
-    in Pervasives.(=) \
+    in Legacy.(=) \
       (Result.catch (Safe_int.mul a) b) (Result.catch (slow_mul a) b))
 *)
 
