@@ -19,6 +19,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
+##V>=5##module Pervasives = Stdlib
+
+(*$inject
+##V>=5##module Pervasives = Stdlib
+*)
+
 module type OrderedType = BatInterfaces.OrderedType
 (** Input signature of the functor {!Set.Make}. *)
 
@@ -1332,7 +1338,7 @@ let of_list l = Concrete.of_list Pervasives.compare l
 (*$Q of_list
   (Q.list Q.small_int) (fun l -> let xs = List.map (fun i -> i mod 5, i) l in \
     let s1 = of_list xs |> enum |> List.of_enum in \
-    let s2 = List.sort_unique Pervasives.compare xs in \
+    let s2 = List.sort_unique Legacy.compare xs in \
     s1 = s2 \
   )
 *)
